@@ -1,23 +1,23 @@
-#!/usr/bin/perl
+#! /usr/local/bin/perl
 
 use strict;
 use warnings;
 use Math::Factor qw(factor match);
 
-our(%form, $ul, $i);
+our (%form, $ul, $i);
 
 #$Math::Factor::Skip_multiple = 1;
     
 my @numbers = qw(9 30107);
 
-my $factors = factor(\@numbers);
-my $matches = match($factors);
+my $factors = factor( \@numbers );
+my $matches = match( $factors );
 
-show_factors($factors);
-show_matches($matches);
+show_factors( $factors );
+show_matches( $matches );
 
 sub show_factors {
-    my $factors = shift;
+    my ($factors) = @_;
 
     print <<'EOT';
 -------
@@ -28,9 +28,11 @@ EOT
     
     local $_;
     for (sort { $a <=> $b } keys %$factors) {
-        local($ul, $,);   
+        local ($ul, $,);   
         $ul = '-' x length;
-        formeval('factors'); write; 
+	
+        formeval( 'factors' ); 
+	write; 
     
         $, = "\t"; 
         print "@{$factors->{$_}}\n\n";
@@ -38,7 +40,7 @@ EOT
 }
 
 sub show_matches {
-    my $matches = shift;   
+    my ($matches) = @_;   
 	
     print <<'EOT';
 -------
@@ -49,18 +51,20 @@ EOT
 
     local $_;
     for (sort { $a <=> $b } keys %$matches) {
-        local($ul, $i);
+        local ($ul, $i);
         $ul = '-' x length;
-        formeval('match_number'); write;
+	
+        formeval( 'match_number' ); 
+	write;
     
-        formeval('match_matches'); 
+        formeval( 'match_matches' ); 
         for ($i = 0; $matches->{$_}[$i]; $i++) { write }
 	print "\n";
     }
 }    
 
 sub formeval {
-    my $ident = shift;
+    my ($ident) = @_;
     
     no warnings 'redefine';
     eval $form{$ident};
